@@ -2,10 +2,9 @@
 mod test {
     use crate::{config::Config, conn::*};
     use tokio::time::timeout;
-    use util::Error;
 
     #[tokio::test]
-    async fn test_multiple_close() -> Result<(), Error> {
+    async fn test_multiple_close() -> Result<()> {
         let server_a = DnsConn::server(
             SocketAddr::new(Ipv4Addr::new(0, 0, 0, 0).into(), 5353),
             Config::default(),
@@ -14,7 +13,7 @@ mod test {
         server_a.close().await?;
 
         if let Err(err) = server_a.close().await {
-            assert_eq!(err, *ERR_CONNECTION_CLOSED);
+            assert!(Error::ErrConnectionClosed.equal(&err));
         } else {
             assert!(false, "expected error, but got ok");
         }
@@ -23,7 +22,7 @@ mod test {
     }
 
     #[tokio::test]
-    async fn test_query_respect_timeout() -> Result<(), Error> {
+    async fn test_query_respect_timeout() -> Result<()> {
         let server_a = DnsConn::server(
             SocketAddr::new(Ipv4Addr::new(0, 0, 0, 0).into(), 5353),
             Config::default(),
