@@ -30,13 +30,13 @@ impl ResourceBody for MxResource {
         mut msg: Vec<u8>,
         compression: &mut Option<HashMap<String, usize>>,
         compression_off: usize,
-    ) -> Result<Vec<u8>, Error> {
+    ) -> Result<Vec<u8>> {
         msg = pack_uint16(msg, self.pref);
         msg = self.mx.pack(msg, compression, compression_off)?;
         Ok(msg)
     }
 
-    fn unpack(&mut self, msg: &[u8], off: usize, _length: usize) -> Result<usize, Error> {
+    fn unpack(&mut self, msg: &[u8], off: usize, _length: usize) -> Result<usize> {
         let (pref, off) = unpack_uint16(msg, off)?;
         self.pref = pref;
         self.mx.unpack(msg, off)
